# Generated by Django 4.2.4 on 2023-08-29 09:30
import logging

from django.db import migrations, models

logger = logging.getLogger(__name__)


def show_with_user_from_relevant_qualification_categories(apps, schema_editor):
    from dynamic_preferences.registries import global_preferences_registry

    global_preferences = global_preferences_registry.manager()
    relevant_categories_pks = {
        category.pk for category in global_preferences["general__relevant_qualification_categories"]
    }

    QualificationCategory = apps.get_model("core", "QualificationCategory")
    for category in QualificationCategory.objects.all():
        category.show_with_user = category.pk in relevant_categories_pks
        logger.info(f"migrate {category.show_with_user=} for {category}")
        category.save()


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0019_userprofile_user_email_ci_uniqueness"),
        ("dynamic_preferences", "0005_auto_20181120_0848"),
    ]

    operations = [
        migrations.AddField(
            model_name="qualificationcategory",
            name="show_with_user",
            field=models.BooleanField(
                default=True,
                verbose_name="Show qualifications of this category everywhere a user is presented.",
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="is_staff",
            field=models.BooleanField(default=False, verbose_name="Administrator"),
        ),
        migrations.RunPython(
            show_with_user_from_relevant_qualification_categories, migrations.RunPython.noop
        ),
    ]
